Documentation
¶
Overview ¶
Package azure is an identity provider that authenticates with azure.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewIdentityProvider ¶
func NewIdentityProvider(p Params) idp.IdentityProvider
NewIdentityProvider creates an azure identity provider with the configuration defined by p.
Types ¶
type Params ¶
type Params struct {
// Name is the name that will be given to the identity provider.
Name string `yaml:"name"`
// Description is the description that will be used with the
// identity provider. If this is not set then Name will be used.
Description string `yaml:"description"`
// Icon contains the URL or path of an icon.
Icon string `yaml:"icon"`
// Domain is the domain with which all identities created by this
// identity provider will be tagged (not including the @ separator).
Domain string `yaml:"domain"`
// ClientID contains the Application Id for the application
// registered at https://apps.dev.microsoft.com.
ClientID string `yaml:"client-id"`
// ClientSecret contains a password type Application Secret for
// the application as generated on
// https://apps.dev.microsoft.com.
ClientSecret string `yaml:"client-secret"`
// Hidden is set if the IDP should be hidden from interactive
// prompts.
Hidden bool `yaml:"hidden"`
}
Click to show internal directories.
Click to hide internal directories.