Documentation
¶
Overview ¶
Package static contains identity providers that validate against a static list of users. This provider is only intended for testing purposes.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewIdentityProvider ¶
func NewIdentityProvider(p Params) idp.IdentityProvider
NewIdentityProvider creates a new static identity provider.
Types ¶
type Params ¶
type Params struct {
// Name is the name that will be given to the identity provider.
Name string `yaml:"name"`
// Description is the description of the IDP shown to the user on
// the IDP selection page.
Description string `yaml:"description"`
// Icon contains the URL or path of an icon.
Icon string `yaml:"icon"`
// Domain is the domain with which all identities created by this
// identity provider will be tagged (not including the @ separator).
Domain string `yaml:"domain"`
// Users is the set of users that are allowed to authenticate, with their
// passwords and list of groups.
Users map[string]UserInfo `yaml:"users"`
// Hidden is set if the IDP should be hidden from interactive
// prompts.
Hidden bool `yaml:"hidden"`
// MatchEmailAddr is a regular expression that is used to determine if
// this identity provider can be used for a particular user email.
MatchEmailAddr string `yaml:"match-email-addr"`
// RequireMFA indicates if this provider requires the use of MFA
RequireMFA bool `yaml:"require-mfa"`
}
type UserInfo ¶
type UserInfo struct {
// Password is the password for the user.
Password string `yaml:"password"`
// Name is the full name of the user.
Name string `yaml:"name"`
// Email is the user e-mail.
Email string `yaml:"email"`
// Groups is the list of groups the user belongs to.
Groups []string `yaml:"groups"`
}
Click to show internal directories.
Click to hide internal directories.